@@ -4,6 +4,7 @@ import sys
 import click
 
 from . import freud_api_crawler as frd
+from . file_utils import flatten_files as flatten
 
 
 @click.command()
@@ -27,13 +28,13 @@ def cli(user, pw, m):
     )
 
 
-@click.command()
-@click.argument('user', envvar='FRD_USER')
-@click.argument('pw', envvar='FRD_PW')
-@click.option('-w', default='9d035a03-28d7-4013-adaf-63337d78ece4', show_default=True)
-@click.option('-s', default='/home/csae8092/freud_data_cli', show_default=True)
-def download_work(user, pw, w, s):
-    """Console script for freud_api_crawler."""
+@click.command()  # pragma: no cover
+@click.argument('user', envvar='FRD_USER')  # pragma: no cover
+@click.argument('pw', envvar='FRD_PW')  # pragma: no cover
+@click.option('-w', default='9d035a03-28d7-4013-adaf-63337d78ece4', show_default=True)  # pragma: no cover
+@click.option('-s', default='/home/csae8092/freud_data_cli', show_default=True)  # pragma: no cover
+def download_work(user, pw, w, s):  # pragma: no cover
+    """Console script to download all manifestations of a singel work."""
     auth_items = frd.get_auth_items(user, pw)
     werk_obj = frd.FrdWerk(
         auth_items=auth_items, werk_id=w
@@ -52,3 +53,16 @@ def download_work(user, pw, w, s):
             fg='green'
         )
     )
+
+
+@click.command()  # pragma: no cover
+@click.option('-s', default='/home/csae8092/freud_data_cli/werke/drei-abhandlungen-zur-sexualtheorie', show_default=True)  # pragma: no cover
+def flatten_files(s):  # pragma: no cover
+    """Console script to flatten XML/TEI files of a work."""
+    flattend = flatten(s)
+    click.echo(
+        click.style(
+            f"finished",
+            fg='green'
+        )
+    )
