@@ -6,7 +6,7 @@ from collections import defaultdict
 import requests
 import lxml.etree as ET
 
-from freud_api_crawler.string_utils import clean_markup, extract_page_nr
+from freud_api_crawler.string_utils import clean_markup, extract_page_nr, always_https
 
 from freud_api_crawler.tei_utils import make_pb
 
@@ -14,19 +14,40 @@ from freud_api_crawler.tei_utils import make_pb
 FRD_API = os.environ.get('FRD_API', 'https://www.freud-edition.net/jsonapi/')
 FRD_USER = os.environ.get('FRD_USER', False)
 FRD_PW = os.environ.get('FRD_PW', False)
-FRD_SESSION = os.environ.get('FRD_SESSION', False)
-FRD_TOKEN = os.environ.get('FRD_TOKEN', False)
 
-SAMPLE_MANIFESTATION = os.path.join(
-    os.path.dirname(__file__),
-    "fixtures",
-    "manifestation.json"
-)
-SAMPLE_MANIFESTATION_PAGE = os.path.join(
-    os.path.dirname(__file__),
-    "fixtures",
-    "manifestation_seite.json"
-)
+
+def get_auth_items(username, password):
+    """ helper function to fetch auth-cookie
+
+    :param username: Drupal-User Username
+    :type username: str
+    :param password: Drupal-User Password
+    :type password: str
+
+    :return: A dict with auth-items `'cookie', 'current_user', 'csrf_token', 'logout_token'`
+    :rtype: dict
+    """
+
+    url = "https://www.freud-edition.net/user/login?_format=json"
+    payload = {
+        "name": username,
+        "pass": password
+    }
+    headers = {
+      'Content-Type': 'application/json',
+    }
+    r = requests.request(
+        "POST", url, headers=headers, data=json.dumps(payload)
+    )
+    auth_items = {
+        'cookie': r.cookies,
+    }
+    for key, value in r.json().items():
+        auth_items[key] = value
+    return auth_items
+
+
+AUTH_ITEMS = get_auth_items(FRD_USER, FRD_PW)
 
 TEI_DUMMY = os.path.join(
     os.path.dirname(__file__),
@@ -49,35 +70,25 @@ class FrdClient():
         """ returns a list of existing API-Endpoints
         :return: A PyLobidPerson instance
         """
-        if self.authenticated:
-            r = requests.get(
-                self.endpoint,
-                auth=(self.user, self.pw),
-                headers={
-                    'Cookie': self.cookie
-                }
-            )
-            result = r.json()
-            d = defaultdict(list)
-            for key, value in result['links'].items():
-                url = value['href']
-                node_type = url.split('/')[-2]
-                d[node_type].append(url)
-            return d
-        else:
-            return {}
 
-    def get_cookie(self):
-        return f"{self.session}={self.token}"
+        r = requests.get(
+            self.endpoint,
+            cookies=self.cookie,
+            allow_redirects=True
+        )
+        result = r.json()
+        d = defaultdict(list)
+        for key, value in result['links'].items():
+            url = value['href']
+            node_type = url.split('/')[-2]
+            d[node_type].append(url)
+        return d
 
     def __init__(
         self,
         out_dir=CUR_LOC,
         endpoint=FRD_API,
-        user=FRD_USER,
-        pw=FRD_PW,
-        session=FRD_SESSION,
-        token=FRD_TOKEN,
+        auth_items={},
         page_size=10,
         limit=10,
         sleep=0.5
@@ -102,11 +113,8 @@ class FrdClient():
         """
         super().__init__()
         self.endpoint = endpoint
-        self.user = user
-        self.pw = pw
-        self.session = session
-        self.token = token
-        self.cookie = self.get_cookie()
+        self.auth_items = auth_items
+        self.cookie = self.auth_items['cookie']
         self.page_size = page_size
         self.limit = limit
         self.sleep = sleep
@@ -116,11 +124,6 @@ class FrdClient():
             "tei": "http://www.tei-c.org/ns/1.0",
             "xml": "http://www.w3.org/XML/1998/namespace",
         }
-        if self.pw and self.user or self.session and self.token:
-            self.authenticated = True
-        else:
-            print("no user and password set")
-            self.authenticated = False
         self.tei_dummy = self.tei_dummy()
         self.out_dir = out_dir
 
@@ -143,10 +146,8 @@ class FrdWerk(FrdClient):
         url = f"{self.werk_ep}/{self.werk_id}"
         r = requests.get(
             self.ep,
-            auth=(self.user, self.pw),
-            headers={
-                'Cookie': self.cookie
-            }
+            cookies=self.cookie,
+            allow_redirects=True
         )
         status_code = r.status_code
         result = r.json()
@@ -163,15 +164,14 @@ class FrdWerk(FrdClient):
             x = None
             response = requests.get(
                 url,
-                auth=(self.user, self.pw),
-                headers={
-                    'Cookie': self.cookie
-                }
+                cookies=self.cookie,
+                allow_redirects=True
             )
             result = response.json()
             links = result['links']
             if links.get('next', False):
-                url = links['next']['href']
+                orig_url = links['next']['href']
+                url = always_https(orig_url)
             else:
                 next_page = False
             for x in result['data']:
@@ -224,21 +224,11 @@ class FrdManifestation(FrdClient):
         """
         r = requests.get(
             f"{self.manifestation_endpoint}?include=field_werk",
-            auth=(self.user, self.pw),
-            headers={
-                'Cookie': self.cookie
-            }
+            cookies=self.cookie,
+            allow_redirects=True
         )
         status_code = r.status_code
-        if status_code != 200:
-            print(
-                f"could not access {self.manifestation_endpoint} because\
-                of {status_code}, using local sample"
-            )
-            with open(SAMPLE_MANIFESTATION) as json_file:
-                result = json.load(json_file)
-        else:
-            result = r.json()
+        result = r.json()
         return result
 
     def get_manifestation_save_path(self):
@@ -293,21 +283,12 @@ class FrdManifestation(FrdClient):
 
         r = requests.get(
             f"{url}?include=field_faksimile",
-            auth=(self.user, self.pw),
-            headers={
-                'Cookie': self.cookie
-            }
+            cookies=self.cookie,
+            allow_redirects=True
         )
 
         status_code = r.status_code
-        if status_code != 200:
-            print(
-                f" {url} -> {status_code} -> using local sample"
-            )
-            with open(SAMPLE_MANIFESTATION_PAGE) as json_file:
-                result = json.load(json_file)
-        else:
-            result = r.json()
+        result = r.json()
         return result
 
     def process_page(self, page_json):
